@@ -290,18 +290,16 @@ void tetisApplyDeepAquiferLossToAquifer(DataFrame outWB, List y,
 
 // [[Rcpp::export(".tetisOverlandFlows")]]
 void tetisOverlandFlows(DataFrame outWB,
-                        IntegerVector waterO, List queenNeigh, List waterQ) {
-  
+                        IntegerVector waterO, List queenNeigh, List waterQ, LogicalVector isChannel) {
+
+  NumericVector ChannelExport=  outWB[WBCOM_ChannelExport];
   NumericVector WatershedExport=  outWB[WBCOM_WatershedExport];
   NumericVector Runoff=  outWB[WBCOM_Runoff];
+  NumericVector Runon=  outWB[WBCOM_Runon];
   NumericVector AquiferExfiltration =  outWB[WBCOM_AquiferExfiltration];
   
   int nX = Runoff.size();
-  // Here runon is an independent vector because runon from rock/artificial/water cells 
-  // has already taken into account previously. This is to process runoff from water balance
-  // and aquifer exfiltration
-  NumericVector Runon(nX,0.0);
-
+  
   for(int i=0;i<nX;i++) {
     //get next cell in order
     int iCell = waterO[i]-1; //Decrease index!!!!
@@ -322,7 +320,11 @@ void tetisOverlandFlows(DataFrame outWB,
         stop("Non-outlet cell with runoff export");
       }
       if(sum(qi)==0.0) { // outlet
-        WatershedExport[iCell] += ri;
+        if(isChannel[iCell]) {
+          ChannelExport[iCell] += ri;
+        } else {
+          WatershedExport[iCell] += ri;
+        }
       }
     }
   }
@@ -332,9 +334,12 @@ void tetisOverlandFlows(DataFrame outWB,
 void tetisSimulationNonSoilCells(DataFrame outWB,
                                  List y,
                                  NumericVector tminVec, NumericVector tmaxVec, NumericVector precVec, NumericVector radVec,
-                                 IntegerVector waterO, List queenNeigh, List waterQ,
+                                 IntegerVector waterO, List queenNeigh, List waterQ, LogicalVector isChannel,
                                  List watershed_control) {
   
+  NumericVector MinTemperature = outWB[WBCOM_MinTemperature];
+  NumericVector MaxTemperature = outWB[WBCOM_MaxTemperature];
+  NumericVector PET = outWB[WBCOM_PET];
   NumericVector Rain = outWB[WBCOM_Rain];
   NumericVector Interception = outWB[WBCOM_Interception];
   NumericVector NetRain = outWB[WBCOM_NetRain];
@@ -345,6 +350,7 @@ void tetisSimulationNonSoilCells(DataFrame outWB,
   NumericVector Snow = outWB[WBCOM_Snow];
   NumericVector Snowmelt = outWB[WBCOM_Snowmelt];
   NumericVector Runon = outWB[WBCOM_Runon];
+  NumericVector ChannelExport = outWB[WBCOM_ChannelExport];
   NumericVector WatershedExport = outWB[WBCOM_WatershedExport];
   
   List tetis_parameters = watershed_control["tetis_parameters"];
@@ -358,6 +364,9 @@ void tetisSimulationNonSoilCells(DataFrame outWB,
   
   for(int i=0;i<nX;i++){
     if(lct[i]=="rock" || lct[i]=="artificial" || lct[i]=="water") {
+      MinTemperature[i] = tminVec[i];
+      MaxTemperature[i] = tmaxVec[i];
+      PET[i] = NA_REAL;
       double tday = meteoland::utils_averageDaylightTemperature(tminVec[i], tmaxVec[i]);
       if(tday<0.0) {
         Snow[i] = precVec[i];
@@ -391,34 +400,6 @@ void tetisSimulationNonSoilCells(DataFrame outWB,
       // Rcout << i<< " Rain " << Rain[i] << " Snow " << Snow[i] << " DeepDrainage " << DeepDrainage[i] << " Snowmelt " << Snowmelt[i] << " Runoff " << Runoff[i] << "\n";
     }
   }
-  //Estimate Runon to wildland/agriculture cells
-  for(int i=0;i<nX;i++) {
-    //get next cell in order
-    int iCell = waterO[i]-1; //Decrease index!!!!
-    //Only distribute runoff if the cell is rock or artificial
-    if(lct[iCell]=="rock" || lct[iCell]=="artificial") {
-      //Assign runoff to runon of downhill neighbours
-      double ri_tot =  Runon[iCell] + Runoff[iCell];
-      if(ri_tot>0.0) {
-        double ri = ri_tot;
-        IntegerVector ni = Rcpp::as<Rcpp::IntegerVector>(queenNeigh[iCell]);
-        NumericVector qi = Rcpp::as<Rcpp::NumericVector>(waterQ[iCell]);
-        if(ni.size()>0) {
-          for(int j=0;j<ni.size();j++)  {
-            Runon[ni[j]-1] += (qi[j]*ri_tot); //decrease index
-            ri -= (qi[j]*ri_tot);
-          }
-        }
-        if((sum(qi)>0.0) && (ri > 0.00001)) {
-          Rcout<< i <<ni.size()<< " "<<qi.size()<<" "<<iCell<< " "<< sum(qi)<< " "<< ri<<"\n";
-          stop("Non-outlet cell with runoff export");
-        }
-        if(sum(qi)==0.0) { // outlet rock/artificial cell
-          WatershedExport[iCell] += ri;
-        }
-      }      
-    }
-  }
 }
 
 // [[Rcpp::export(".tetisCopySoilResultsToOutput")]]
@@ -493,4 +474,114 @@ void tetisCopySoilResultsToOutput(List y, List soilCellResults, List output,
       }
     }
   }
+  
+  if(output.containsElementNamed("WatershedStand")) {
+    DataFrame outStand = as<DataFrame>(output["WatershedStand"]);
+    NumericVector LAI = outStand[STCOM_LAI];
+    NumericVector LAIherb = outStand[STCOM_LAIherb];
+    NumericVector LAIlive = outStand[STCOM_LAIlive];
+    NumericVector LAIexpanded = outStand[STCOM_LAIexpanded];
+    NumericVector LAIdead = outStand[STCOM_LAIdead];
+    NumericVector Cm = outStand[STCOM_Cm];
+    NumericVector LgroundPAR = outStand[STCOM_LgroundPAR];
+    NumericVector LgroundSWR = outStand[STCOM_LgroundSWR];
+    for(int i=0;i<nX;i++){
+      if(land_cover_type[i] == "wildland") {
+        List lr = soilCellResults[i];
+        List sr = lr["simulation_results"];
+        NumericVector Stand = sr["Stand"];
+        LAI[i] = Stand["LAI"];
+        LAIherb[i] = Stand["LAIherb"];
+        LAIlive[i] = Stand["LAIlive"];
+        LAIexpanded[i] = Stand["LAIexpanded"];
+        LAIdead[i] = Stand["LAIdead"];
+        Cm[i] = Stand["Cm"];
+        LgroundPAR[i] = Stand["LgroundPAR"];
+        LgroundSWR[i] = Stand["LgroundSWR"];
+      }
+    }
+  }
+  
+  if(output.containsElementNamed("WatershedCarbonBalance")) {
+    DataFrame outCB = as<DataFrame>(output["WatershedCarbonBalance"]);
+    NumericVector GrossPrimaryProduction = outCB[CBCOM_GrossPrimaryProduction];
+    NumericVector MaintenanceRespiration = outCB[CBCOM_MaintenanceRespiration];
+    NumericVector SynthesisRespiration = outCB[CBCOM_SynthesisRespiration];
+    NumericVector NetPrimaryProduction = outCB[CBCOM_NetPrimaryProduction];
+    for(int i=0;i<nX;i++){
+      if(land_cover_type[i] == "wildland") {
+        List lr = soilCellResults[i];
+        List sr = lr["simulation_results"];
+        NumericVector CarbonBalance = sr["CarbonBalance"];
+        GrossPrimaryProduction[i] = CarbonBalance["GrossPrimaryProduction"];
+        MaintenanceRespiration[i] = CarbonBalance["MaintenanceRespiration"];
+        SynthesisRespiration[i] = CarbonBalance["SynthesisRespiration"];
+        NetPrimaryProduction[i] = CarbonBalance["NetPrimaryProduction"];
+      }
+    }
+  }
+  
+  if(output.containsElementNamed("WatershedBiomassBalance")) {
+    DataFrame outBB = as<DataFrame>(output["WatershedBiomassBalance"]);
+    NumericVector StructuralBalance = outBB[BBCOM_StructuralBalance];
+    NumericVector LabileBalance = outBB[BBCOM_LabileBalance];
+    NumericVector PlantBalance = outBB[BBCOM_PlantBalance];
+    NumericVector MortalityLoss = outBB[BBCOM_MortalityLoss];
+    NumericVector CohortBalance = outBB[BBCOM_CohortBalance];
+    for(int i=0;i<nX;i++){
+      if(land_cover_type[i] == "wildland") {
+        List lr = soilCellResults[i];
+        List sr = lr["simulation_results"];
+        DataFrame pbb = Rcpp::as<Rcpp::DataFrame>(sr["PlantBiomassBalance"]);
+        StructuralBalance[i] = sum(Rcpp::as<Rcpp::NumericVector>(pbb["StructuralBiomassBalance"]));
+        LabileBalance[i] = sum(Rcpp::as<Rcpp::NumericVector>(pbb["LabileBiomassBalance"]));
+        PlantBalance[i] = sum(Rcpp::as<Rcpp::NumericVector>(pbb["PlantBiomassBalance"]));
+        MortalityLoss[i] = sum(Rcpp::as<Rcpp::NumericVector>(pbb["MortalityBiomassLoss"]));
+        CohortBalance[i] = sum(Rcpp::as<Rcpp::NumericVector>(pbb["CohortBiomassBalance"]));
+      }
+    }
+  }
+}
+
+
+// [[Rcpp::export(".tetisChannelRouting")]]
+void tetisChannelRouting(NumericVector ChannelExport, NumericVector WatershedExport,
+                         LogicalVector isChannel, LogicalVector isOutlet, 
+                         IntegerVector target_outlet, IntegerVector distance_to_outlet, List outlet_backlog,
+                         List watershed_control, double patchsize) {
+  List tetis_parameters = watershed_control["tetis_parameters"];
+  double channel_flow_speed = tetis_parameters["channel_flow_speed"];
+  
+  int nX = ChannelExport.size();  
+  //Assign channel export to outlet's backlog
+  for(int i=0;i<nX;i++) {
+    if(isChannel[i]) {
+      if(ChannelExport[i]>0.0) {
+        int target = target_outlet[i] - 1; //Decrease index by one in C++
+        NumericVector backlog = Rcpp::as<Rcpp::NumericVector>(outlet_backlog[target]);
+        int pos = floor((distance_to_outlet[i]*std::sqrt(patchsize)) / (3600.0*24.0*channel_flow_speed));
+        if(pos>=backlog.size()) {
+          Rcout<<"Channel: "<< i+1<< " Outlet: "<< target +1 << " Distance "<< distance_to_outlet[i] <<" Position: " << pos << " Backlog size: " << backlog.size() <<"\n";
+          stop("Outlet backlog position beyond length\n"); 
+        }
+        backlog[pos] = (backlog[pos] + ChannelExport[i]);
+        // Rcout<< i << " outlet "<< target + 1 <<" pos " << pos << " channel export " << ChannelExport[i] <<" backlog: " << backlog[pos] << "\n";
+        ChannelExport[i]  = 0.0;
+      }
+    }
+  }
+  //For each channel outlet, move backlog one day and generate watershed export
+  for(int i=0;i<nX;i++) {
+    if(isOutlet[i]) {
+      NumericVector backlog = Rcpp::as<Rcpp::NumericVector>(outlet_backlog[i]);
+      WatershedExport[i] = backlog[0];
+      // if(backlog[0]>0.0) Rcout << " outlet " << i + 1<< " backlog[0] " << backlog[0] <<"\n";
+      if(backlog.size()>1) {
+        for(int j=1; j<backlog.size(); j++) {
+          backlog[j-1] = backlog[j];
+        }
+      }
+      backlog[backlog.size()-1] = 0.0;
+    }
+  }
 }
